/*
** Module   : HQLFunction.java
** Abstract : Annotation used for identifying HQL mapped functions used by PL.
**
** Copyright (c) 2014, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 OM  20140728 Created initial version.
*/

package com.goldencode.p2j.persist.pl;

import java.lang.annotation.*;

/**
 * Annotation for <code>Functions</code> and <code>Operators</code> methods exposed as UDF HQL
 * functions invoked in SQL via some kind of PL.
 * Methods that do not have this annotation should not be mapped as SQL UDF.
 */
@Target(ElementType.METHOD)         // Annotation can only be applied to methods.
@Retention(RetentionPolicy.RUNTIME) // Annotation will be accessible at runtime via reflection.
public @interface HQLFunction
{
   /** 
    * The name of the UDF function from SQL.
    * If the name is empty, then the name of the java method is to be used as UDF name.
    */
   String name() default "";
   
   /** Reports whether this is a immutable (cache-able) or volatile java method. */
   boolean immutable() default true;
}
